From 83f58c975edf74265a2600eea627e360b19d56cc Mon Sep 17 00:00:00 2001
From: "Joachim Wuttke (o)" <j.wuttke@fz-juelich.de>
Date: Fri, 10 Jun 2016 16:14:03 +0200
Subject: [PATCH] further simplification

---
 Core/TestMachinery/FutestSuite.cpp | 3 ---
 Core/TestMachinery/FutestSuite.h   | 7 +++----
 2 files changed, 3 insertions(+), 7 deletions(-)

diff --git a/Core/TestMachinery/FutestSuite.cpp b/Core/TestMachinery/FutestSuite.cpp
index d289e204c8d..8b03272939b 100644
--- a/Core/TestMachinery/FutestSuite.cpp
+++ b/Core/TestMachinery/FutestSuite.cpp
@@ -33,7 +33,6 @@ FutestSuite::FutestSuite()
     , m_ft_distribution_2d(0)
     , m_ff_registry(0)
     , m_ft2d_registry(0)
-    , m_current_component(0)
 {
 }
 
@@ -59,7 +58,6 @@ int FutestSuite::execute(int argc, char** argv) {
 
     // initialize subtest registry
     std::vector<std::string> subtest_names;
-    m_current_component = 0;
     if       (m_info->m_subtest_type == "None") {
         subtest_names.push_back("Default");
     } else if(m_info->m_subtest_type == "FormFactorsRegistry") {
@@ -76,7 +74,6 @@ int FutestSuite::execute(int argc, char** argv) {
     // run and analyze subtests
     int number_of_failed_tests = 0;
     for (size_t i = 0; i < n_subtests; ++i) {
-        m_current_component = i;
         m_subtest_name = subtest_names[i];
         if(m_ff_registry) {
             delete m_formfactor;
diff --git a/Core/TestMachinery/FutestSuite.h b/Core/TestMachinery/FutestSuite.h
index b10b57b7843..08226b58d12 100644
--- a/Core/TestMachinery/FutestSuite.h
+++ b/Core/TestMachinery/FutestSuite.h
@@ -28,8 +28,8 @@
 //! @class FutestSuite
 //! @brief To execute one functional test of given name.
 
 //! Used in functional tests CoreSuite, PydumpSuite, GUISuite, where it is
 //! subclassed as a singleton. The only call is instance().execute(argc, argv).
 
 //! When processing execute, dependent classes will call back getFutest().
 //! Certain tests have subtests; they will call back getFormFactor() etc.
@@ -41,8 +41,8 @@ public:
     virtual ~FutestSuite();
 
     int execute(int argc, char** argv);
-    virtual class IFutest* getFutest() const = 0;
 
+    virtual class IFutest* getFutest() const = 0; //!< overloaded in (Core|Pydump|GUI)Suite.cpp
     virtual class IFormFactor* getFormFactor() const;
     virtual class IFTDistribution2D* getFTDistribution2D() const;
 
@@ -64,7 +64,6 @@ protected:
 
     class TestFormFactorsRegistry* m_ff_registry;
     class TestFTDistribution2DRegistry* m_ft2d_registry;
-    size_t m_current_component;
     std::string m_subtest_name;
 };
 
@@ -28,8 +28,8 @@
 //! @brief To execute one functional test of given name.
 
-//! Used in functional tests CoreSuite, PydumpSuite, GUISuite, where it is
-//! subclassed as a singleton. The only call is instance().execute(argc, argv).
+//! Used in functional tests (Core|Pydump|GUI)Suite, where it is subclassed
+//! as a singleton, and called through instance().execute(argc, argv).
 
 //! When processing execute, dependent classes will call back getFutest().
-- 
GitLab